Skip to contents

Run all tests for a data set.

Usage

run_data_tests(
  .path = getwd(),
  name,
  overwrite_icon = TRUE,
  overwrite_version = TRUE
)

Arguments

.path

Path to the eatDataTest repository. Defaults to the current working directory.

name

Name of the data set.

overwrite_icon

Should the result icon in the tests folder be overwritten?

overwrite_version

Should the version number in the tests folder be overwritten?

Value

Creates a test result icon. Returns NULL.

Examples

## tbd