Skip to contents

Add the infrastructure for using the directory as aeatDataTest repository. This includes

  • a data folder

  • a changelogs folder

  • a tests folder

  • a diff folder

  • a Readme.md containing the following elements: a table to list all data sets and instructions on how to use the repository for data contributers.

Usage

setup_eatDataTest(.path = getwd())

Arguments

.path

Path to the eatDataTest repository. Defaults to the current working directory.

Value

Creates repository infrastructure. Returns a markdown snippet.

Examples

## tbd