Add the infrastructure for using the directory as aeatDataTest repository. This includes
a
datafoldera
changelogsfoldera
testsfoldera
difffoldera
Readme.mdcontaining the following elements: a table to list all data sets and instructions on how to use the repository for data contributers.
Usage
setup_eatDataTest(.path = getwd())